@@ -8,7 +8,7 @@ use Getopt::Type::Tiny qw(get_opts Str Int);
 use Data::Printer;
 
 unless (@ARGV) {
-    @ARGV = qw(--foo value_of_foo --bar 12 --verbose);
+    local @ARGV = qw(--foo value_of_foo --bar 12 --verbose);
 }
 
 my %options = get_opts(
@@ -30,7 +30,7 @@ example.pl - Example of Getopt::Type::Tiny
 
 =head1 VERSION
 
-version 0.02
+version 0.03
 
 =head1 SYNOPSIS
 
